@@ -11,7 +11,7 @@ assert WialonError
 __author__ = "Alex Chernetsky chal@gurtam.com"
 __copyright__ = ("Copyright 2013, Gurtam; ",)
 
-__credits__ = ["Alex Chernetsky", ]
-__version__ = "1.0.2"
+__credits__ = ["Alex Chernetsky", "Aleksey Shmigelski"]
+__version__ = "1.0.6"
 
 __all__ = ["Wialon"]
