@@ -3,8 +3,9 @@
 
 try:
     from urllib import urlencode
+    from urlparse import urljoin
 except Exception:
-    from urllib.parse import urlencode
+    from urllib.parse import urlencode, urljoin
 
 try:
     from urllib2 import Request, urlopen, HTTPError, URLError
@@ -48,11 +49,11 @@ class WialonError(Exception):
             pass
 
     def __unicode__(self):
+        explanation = self._text
         if (self._code in WialonError.errors):
-            self._text = " ".join([WialonError.errors[self._code], self._text])
+            explanation = " ".join([WialonError.errors[self._code], self._text])
 
-        message = u'{error} ({code})'.format(error=self._text,
-                                             code=self._code)
+        message = u'{error} ({code})'.format(error=explanation, code=self._code)
         return u'WialonError({message})'.format(message=message)
 
     def __str__(self):
@@ -71,14 +72,16 @@ class Wialon(object):
         self.__default_params = {}
         self.__default_params.update(extra_params)
 
-        self.__base_api_url = (
-            '{scheme}://{host}:{port}/wialon/ajax.html?'.format(
+        self.__base_url = (
+            '{scheme}://{host}:{port}'.format(
                 scheme=scheme,
                 host=host,
                 port=port
             )
         )
 
+        self.__base_api_url = urljoin(self.__base_url, 'wialon/ajax.html?')
+
     @property
     def sid(self):
         return self._sid
@@ -93,28 +96,38 @@ class Wialon(object):
         """
         self.__default_params.update(params)
 
+    def avl_evts(self):
+        """
+        Call avl_event request
+        """
+        url = urljoin(self.__base_url, 'avl_evts')
+        params = {
+            'sid': self.sid
+        }
+
+        return self.request('avl_evts', url, params)
+
     def call(self, action, *argc, **kwargs):
         """
         Call the API method provided with the parameters supplied.
         """
-        url = self.__base_api_url
 
         if (not kwargs):
-            # List params for batch 
+            # List params for batch
             params = json.dumps(argc, ensure_ascii=False)
         else:
             params = json.dumps(kwargs, ensure_ascii=False)
-
         params = {
             'svc': action.replace('_', '/', 1),
             'params': params.encode("utf-8"),
             'sid': self.sid
         }
-
         all_params = self.__default_params.copy()
         all_params.update(params)
-        url_params = urlencode(all_params)
+        return self.request(action, self.__base_api_url, all_params)
 
+    def request(self, action, url, params):
+        url_params = urlencode(params)
         data = url_params.encode('utf-8')
         try:
             request = Request(url, data)
@@ -125,14 +138,20 @@ class Wialon(object):
         except URLError as e:
             raise WialonError(0, unicode(e))
 
+        content_type = response.info().getheader('Content-Type')
+        result = response_content.decode('utf-8', errors='ignore')
         try:
-            result = json.loads(response_content.decode('utf-8'))
+            if content_type == 'application/json':
+                result = json.loads(result)
         except ValueError as e:
             raise WialonError(
+                0,
                 u"Invalid response from Wialon: {0}".format(e),
             )
+
         if (isinstance(result, dict) and 'error' in result):
             raise WialonError(result['error'], action)
+
         errors = []
         if isinstance(result, list):
             # Check for batch errors
@@ -141,9 +160,11 @@ class Wialon(object):
                     continue
                 if "error" in elem:
                     errors.append("%s (%d)" % (WialonError.errors[elem["error"]], elem["error"]))
+
         if (errors):
             errors.append(action)
             raise WialonError(0, " ".join(errors))
+
         return result
 
     def __getattr__(self, action_name):
@@ -156,11 +177,12 @@ class Wialon(object):
 
         return get.__get__(self)
 
-
 if __name__ == '__main__':
     try:
         wialon_api = Wialon()
         result = wialon_api.core_login(user='wialon_test', password='test')
         wialon_api.sid = result['eid']
+        result = wialon_api.avl_evts()
     except WialonError:
         pass
+
